@@ -27,3 +27,7 @@ class APIException(Exception):
 
 class TimeoutException(Exception):
     """Define a timeout error."""
+
+
+class AuthorizationError(Exception):
+    """Represents an authorization error."""
